==> suaidoc-0.2.1.tar.gz: suaidoc-0.2.1/README.md <==
# SUAIDOC - docs for SUAI

# 🏗️ UNDER_WORK 🏗️

Это утилита не стремится строго следовать ГОСТ 7.32. Прежде всего утилита предназначена для **облегчения** написания отчетов *студентов*. Поэтому часть стандартов, которая усложнит написание, использование или структурирование - незначительно изменены. Для более комплексных научных работ, стоит выбрать другие решения, например xxx.

## Установка

WIP

Утилита является Python3 пакетом, поэтому для установки достаточно в терминале написать:

```bash
pip install suaidoc
```

или

```bash
pip3 install suaidoc
```

Далее перезагрузите терминал, и если все прошло хорошо, то при вызове `suaidoc` вы увидите:

```text
Usage: suaidoc [OPTIONS] COMMAND [ARGS]...
<...>
```

Теперь нужно установить утилиты, требуемые для работы:
- *pandoc* - для генерации MD в PDF
- *wkhtmltopdf* - для генерации титульной страницы.
- *LaTeX (MiKTeX)* - для придания стиля PDF страницы.

Установка для конкретных ОС:

### macOS

Установите brew и напишите в терминал:

```zsh
brew install pandoc
brew install wkhtmltopdf
brew install --cask mactex-no-gui
```

Теперь все готово к написанию отчетов!

### Windows

Рекомендуется использовать choco во избежание проблем:

```powershell
choco install pandoc
choco install wkhtmltopdf
choco install miktex.install
```

Если не установился какой-либо компонент, то нужно установить его вручную.

### Установка вручную

#### Pandoc

1) Перейдите на [сайт Pandoc](https://pandoc.org/installing.html) и выберите нужный установщик.
2) **Убедитесь**, что выбрана настройка для добавления pandoc в `PATH`!
3) После установки проверьте, что *pandoc* можно вызвать из терминала.

#### wkhtmltopdf

1) Перейдите на [сайт wkhtmltopdf](https://wkhtmltopdf.org) и выберите нужный установщик.
2) Запомните расположение, куда был установлен *wkhtmltopdf*.
3) Скорее всего, после установки *wkhtmltopdf* не будет добавлен в `PATH`. Поэтому добавьте путь из предыдущего шага к `PATH`.
4) Проверьте, что *wkhtmltopdf* можно вызвать из терминала.

#### LaTeX

*MiKTeX* используется из-за удобства и нужных встроенных пакетов.

Для macOS можно использовать [MacTeX](https://tug.org/mactex/).

1) Перейдите на [сайт MikTex](https://miktex.org/download) и выберите нужный установщик.
2) Следуйте шагам установки, **обязательно** выбрав опцию для автоматического обновления.
3) Запустите приложение *MikTex console* и на главной странице проверьте наличие обновлений.

## Пример

WIP

## Команды

WIP

### --help

WIP

### create

WIP

### template

WIP

==> suaidoc-0.2.3.tar.gz: suaidoc-0.2.3/README.md <==
# SUAIDOC - docs for SUAI

# 🏗️ UNDER_WORK 🏗️

Это утилита не стремится строго следовать ГОСТ 7.32. Прежде всего утилита предназначена для **облегчения** написания отчетов *студентов*. Поэтому часть стандартов, которая усложнит написание, использование или структурирование - незначительно изменены. Для более комплексных научных работ, стоит выбрать другие решения, например xxx.

## Установка

WIP

Утилита является Python3 пакетом, поэтому для установки достаточно в терминале написать:

```bash
pip install suaidoc --upgrade
```

или

```bash
pip3 install suaidoc --upgrade
```

Далее перезагрузите терминал, и если все прошло хорошо, то при вызове `suaidoc` вы увидите:

```text
Usage: suaidoc [OPTIONS] COMMAND [ARGS]...
<...>
```

Теперь нужно установить утилиты, требуемые для работы:
- *pandoc* - для генерации MD в PDF
- *wkhtmltopdf* - для генерации титульной страницы.
- *LaTeX (MiKTeX)* - для придания стиля PDF страницы.

Установка для конкретных ОС:

**ЧАСТЬ СПОСОБОВ ЕЩЕ НЕ ПРОТЕСТИРОВАНА**

### macOS

Установите brew и напишите в терминал:

```zsh
brew install pandoc
brew install wkhtmltopdf
brew install --cask mactex-no-gui
```

Теперь все готово к написанию отчетов!

### Windows

Рекомендуется использовать choco во избежание проблем:

```powershell
choco install pandoc
choco install wkhtmltopdf
choco install miktex.install
```

Если не установился какой-либо компонент, то нужно установить его вручную.

### Установка вручную

#### Pandoc

1) Перейдите на [сайт Pandoc](https://pandoc.org/installing.html) и выберите нужный установщик.
2) **Убедитесь**, что выбрана настройка для добавления pandoc в `PATH`!
3) После установки проверьте, что *pandoc* можно вызвать из терминала.

#### wkhtmltopdf

1) Перейдите на [сайт wkhtmltopdf](https://wkhtmltopdf.org) и выберите нужный установщик.
2) Запомните расположение, куда был установлен *wkhtmltopdf*.
3) Скорее всего, после установки *wkhtmltopdf* не будет добавлен в `PATH`. Поэтому добавьте путь из предыдущего шага к `PATH`.
4) Проверьте, что *wkhtmltopdf* можно вызвать из терминала.

#### LaTeX

*MiKTeX* используется из-за удобства и нужных встроенных пакетов.

Для macOS можно использовать [MacTeX](https://tug.org/mactex/).

1) Перейдите на [сайт MikTex](https://miktex.org/download) и выберите нужный установщик.
2) Следуйте шагам установки, **обязательно** выбрав опцию для автоматического обновления.
3) Запустите приложение *MikTex console* и на главной странице проверьте наличие обновлений.

## Пример

WIP

## Команды

WIP

### --help

WIP

### create

WIP

### template

WIP
